<?php

/*
   Script Name:
      fileListing

   Description:
      This script will generate an HTML formatted listing of files in a specified
      directory, for a specified user, on a specified remote server.  The ssh passphase/
      password for the server/user must be stored in the "Keychain" for the user on the
      client machine.

   Usage:
      /usr/bin/php fileListing.php  username  serverName  listRecent  directoryPath

   Modification History:
      27 September 2009  Original Code (Philip Salvaggio, Carl Salvaggio)
      15 February 2010   Added file count reporting (Carl Salvaggio)
      16 February 2010   Modified file count reporting to use an XML-like tag
                         structure (Philip Salvaggio, Carl Salvaggio)
      30 January 2011    Added a checkbox to allow for listing of files
                         from most recently created/modified (Carl Salvaggio)
      22 March 2012      Fixed a bug that caused directory listings that placed
                         "/" characters on the end of directories to list
                         these entries improperly (default "ls" behavior is
                         now enforced) (Philip Salvaggio, Carl Salvaggio)
*/

/*
   Parse the command line arguments (username, serverName and listRecent [boolean] are required,
   directoryPath may be left blank to indicate the user's home directory), warn the user if
   the supplied information is incomplete
*/
   if ( $argc < 4 ) return;
   $username = $argv[1];
   $serverName = $argv[2];
   $listRecent = $argv[3];
   $directoryPath = ( $argc == 4 ) ? "" : $argv[4];

   if ( count( explode( ".", $serverName ) ) < 3 ) {
      print "The provided server name is not valid";
      print "<br>\n";
	  return;
   }

/*
   Construct and execute the Unix command line
*/
   if ( $listRecent == "true" ) {
      $listCommand = " \"\ls -Ft ";
   } else {
      $listCommand = " \"\ls -F ";
   }

   $commandLine = "ssh " . $username . "@" . $serverName . $listCommand . $directoryPath . "\"";

   exec( $commandLine, $fileListing, $status );

/*
   Check the return status from ssh
        0 - indicates success and that the listing can be created
        2 - indicates a failure (bad directory path)
      255 - indicates a failure (bad username/server)
*/
   $numberFiles = 0;
   switch ( $status ) {
      case 0:
         foreach ( $fileListing as $file ) {
            print $file;
            print "<br>\n";
            $numberFiles += 1;
         }
         break;
      case 2:
         print "The provided directory was not found on the server";
         break;
      case 255:
         print "The authentication information provided on the information panel may not be accurate";
         print "<br>\n";
         print "<br>\n";
         print "-OR-";
         print "<br>\n";
         print "<br>\n";
         print "The SSH password (passphase) for the username / server indicated may not be stored in the current user's \"Keychain\"";
         print "<br>\n";
         break;
   }

/*
   If file(s) were found, print the number of file(s) in a terminating
   XML-like tag structure
*/
   switch ( $numberFiles ) {
      case 0:
         break;
      default:
         print "<numberFiles>";
         print $numberFiles;
         print "</numberFiles>";
         break;
   }

?>